@@ -14,6 +14,7 @@ limitations under the License.
 package commands
 
 import (
+	"encoding/json"
 	"errors"
 	"fmt"
 	"io"
@@ -143,6 +144,13 @@ To create new contexts, see the help for `+"`"+`doctl auth init`+"`"+`.`, Writer
 	AddStringFlag(cmdAuthList, doctl.ArgFormat, "", "", "Columns for output in a comma-separated list. Possible values: `text`")
 	cmdAuthList.Example = `The following example lists the available contexts with the ` + "`" + `--format` + "`" + ` flag: doctl auth list`
 
+	cmdAuthToken := cmdBuilderWithInit(cmd, RunAuthToken, "token", "Display current authentication context API token", `Display the current authentication context's token that you created with `+"`"+`doctl auth init`+"`"+`.
+
+To switch between the contexts use `+"`"+`doctl auth switch --context <name>`+"`"+`, where `+"`"+`<name>`+"`"+` is one of the contexts from: `+"`"+`doctl auth list`+"`"+`
+
+To create new contexts, see the help for `+"`"+`doctl auth init`+"`"+`.`, Writer, false, aliasOpt("t"))
+	cmdAuthToken.Example = `The following example displays the token of the current context: doctl auth token`
+
 	return cmd
 }
 
@@ -218,11 +226,23 @@ func RunAuthList(c *CmdConfig) error {
 	}
 	contexts := viper.GetStringMap("auth-contexts")
 
-	displayAuthContexts(c.Out, context, contexts)
+	if viper.GetString("output") == "json" {
+		displayAuthContextsJSON(c.Out, context, contexts)
+	} else {
+		displayAuthContexts(c.Out, context, contexts)
+	}
+
 	return nil
 }
 
-func displayAuthContexts(out io.Writer, currentContext string, contexts map[string]any) {
+// RunAuthToken displays the current context token from the user's doctl config.
+func RunAuthToken(c *CmdConfig) error {
+	accessToken := c.getContextAccessToken()
+	fmt.Println(accessToken)
+	return nil
+}
+
+func ensureDefaultContextAndKeysOrder(contexts map[string]any) []string {
 	// Because the default context isn't present on the auth-contexts field,
 	// we add it manually so that it's always included in the output, and so
 	// we can check if it's the current context.
@@ -236,6 +256,31 @@ func displayAuthContexts(out io.Writer, currentContext string, contexts map[stri
 	}
 	sort.Strings(keys)
 
+	return keys
+}
+
+func displayAuthContextsJSON(out io.Writer, currentContext string, contexts map[string]any) {
+	type contextJSON struct {
+		Name    string `json:"name"`
+		Current bool   `json:"current"`
+	}
+
+	var contextsJSON []contextJSON
+
+	keys := ensureDefaultContextAndKeysOrder(contexts)
+	for _, ctx := range keys {
+		contextsJSON = append(contextsJSON, contextJSON{
+			Name:    ctx,
+			Current: ctx == currentContext,
+		})
+	}
+
+	jsonData, _ := json.MarshalIndent(contextsJSON, "", "  ")
+	fmt.Fprintln(out, string(jsonData))
+}
+
+func displayAuthContexts(out io.Writer, currentContext string, contexts map[string]any) {
+	keys := ensureDefaultContextAndKeysOrder(contexts)
 	for _, ctx := range keys {
 		if ctx == currentContext {
 			fmt.Fprintln(out, ctx, "(current)")
