@@ -22,6 +22,7 @@ import (
 	"time"
 
 	"github.com/digitalocean/doctl"
+
 	"github.com/fatih/color"
 	"github.com/mattn/go-isatty"
 	"github.com/spf13/cobra"
@@ -183,11 +184,15 @@ func addCommands() {
 	DoitCmd.AddCommand(Projects())
 	DoitCmd.AddCommand(Version())
 	DoitCmd.AddCommand(Registry())
+	DoitCmd.AddCommand(Registries())
 	DoitCmd.AddCommand(VPCs())
 	DoitCmd.AddCommand(Network())
 	DoitCmd.AddCommand(OneClicks())
 	DoitCmd.AddCommand(Monitoring())
 	DoitCmd.AddCommand(Serverless())
+	DoitCmd.AddCommand(Spaces())
+	DoitCmd.AddCommand(GradientAI())
+	DoitCmd.AddCommand(Nfs())
 }
 
 func computeCmd() *Command {
@@ -207,6 +212,7 @@ func computeCmd() *Command {
 	cmd.AddCommand(Droplet())
 	cmd.AddCommand(DropletAutoscale())
 	cmd.AddCommand(Domain())
+	cmd.AddCommand(VPCNATGateway())
 	cmd.AddCommand(Firewall())
 	cmd.AddCommand(ReservedIP())
 	cmd.AddCommand(ReservedIPAction())
@@ -281,6 +287,17 @@ func AddIntFlag(cmd *Command, name, shorthand string, def int, desc string, opts
 	}
 }
 
+// AddFloatFlag adds an float flag to a command.
+func AddFloatFlag(cmd *Command, name, shorthand string, def float64, desc string, opts ...flagOpt) {
+	fn := flagName(cmd, name)
+	cmd.Flags().Float64P(name, shorthand, def, desc)
+	viper.BindPFlag(fn, cmd.Flags().Lookup(name))
+
+	for _, o := range opts {
+		o(cmd, name, fn)
+	}
+}
+
 // AddBoolFlag adds a boolean flag to a command.
 func AddBoolFlag(cmd *Command, name, shorthand string, def bool, desc string, opts ...flagOpt) {
 	fn := flagName(cmd, name)
